# OpenPLM

My personal extention of huggingface/transformers


## Install

```sh
pip install openplm
```


## Tree

```sh
openplm/          # Python package.
├── constant.py   # Define some constant values.
├── apis          # Some easy-use apis.
├── metrics       # Some metrics.
├── models        # Some transformers-style models, which is an extension of huggingface/transformers.
└── utils         # Some utils.

docs/             # Some documents.
examples/         # Some example projects implemented with transformers or openplm.
researchs/        # Some research projects implemented with transformers or openplm.
tests/            # Test cases.
```
